// -*- C++ -*-

//=============================================================================
/**
 *  @file    RequestInterceptor_Adapter.cpp
 *
 *   This file an adapter class to simplify the support of
 *   interceptors.
 */
//=============================================================================

#include "tao/RequestInterceptor_Adapter.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO::RequestInterceptor_Adapter::~RequestInterceptor_Adapter ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
